Crate all_pairs_hamming

Crate all_pairs_hamming 

This library provides a fast and compact all pairs similarity search (or similarity self-join) on binary sketches in the Hamming space. The algorithm employs a modified variant of the sketch sorting approach, a combination of the multiple sorting and the multi-index approach.

Re-exports

pub use chunked_join::ChunkedJoiner;

Modules

chunked_join
A fast and compact implementation of similarity self-join on binary sketches in the Hamming space.
errors
Error definitions.
multi_sort
The core part of crate::ChunkedJoiner.
simple_join
A naive implementation of similarity self-join on binary sketches in the Hamming space.
sketch
Traits of binary short sketches of primitive integer types.