pub struct MultiSort<S> { /* private fields */ }Expand description
The core part of crate::ChunkedJoiner
implementing the multiple sorting algorithm for short binary sketches.
Complexities
The time and memory complexities are linear in the input and output size.
References
- Uno. Multi-sorting algorithm for finding pairs of similar short substrings from large-scale string data. Knowl Inf Syst 25, 229–251 (2010).
Implementations
Sourceimpl<S> MultiSort<S>where
S: Sketch,
impl<S> MultiSort<S>where
S: Sketch,
Sourcepub fn num_blocks(self, num_blocks: usize) -> Self
pub fn num_blocks(self, num_blocks: usize) -> Self
Sets the number of blocks.
Sourcepub const fn threshold_in_sort(self, threshold_in_sort: usize) -> Self
pub const fn threshold_in_sort(self, threshold_in_sort: usize) -> Self
Sets the size threshold for partial sorting. If the partial size is smaller than the threshold, a quicksort is used; otherwise, a radix sort is used.