This library provides a fast and compact all pairs similarity search (or similarity self-join) on binary sketches in the Hamming space. The algorithm employs a modified variant of the sketch sorting approach, a combination of the multiple sorting and the multi-index approach.
Re-exports
pub use chunked_join::ChunkedJoiner;
Modules
- chunked_
join - A fast and compact implementation of similarity self-join on binary sketches in the Hamming space.
- errors
- Error definitions.
- multi_
sort - The core part of
crate::ChunkedJoiner. - simple_
join - A naive implementation of similarity self-join on binary sketches in the Hamming space.
- sketch
- Traits of binary short sketches of primitive integer types.